climb: Climb a forest from parents to children

View source: R/climb.R

climbR Documentation

Climb a forest from parents to children

Description

Climb a forest from parents to children with one or more node names.

Usage

climb(.data, ..., .recurse = TRUE, .deep)

Arguments

.data

A forest.

...

A list of node names to climb the forest.

.recurse

Whether to search recursively by node names or not?

.deep

(Deprecated) Whether to search recursively by node names or not?

Value

A forest.


timbr documentation built on July 17, 2026, 1:07 a.m.